@@ -36,24 +36,41 @@ var debianLicenseText = map[string]string{
  you may not use this file except in compliance with the License.
  You may obtain a copy of the License at
  .
- http://www.apache.org/licenses/LICENSE-2.0
+ https://www.apache.org/licenses/LICENSE-2.0
  .
  Unless required by applicable law or agreed to in writing, software
  distributed under the License is distributed on an "AS IS" BASIS,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  See the License for the specific language governing permissions and
  limitations under the License.
- .
+Comment:
  On Debian systems, the complete text of the Apache version 2.0 license
- can be found in "/usr/share/common-licenses/Apache-2.0".
-`,
+ can be found in "/usr/share/common-licenses/Apache-2.0".`,
+
+	"Expat": ` Permission is hereby granted, free of charge, to any person obtaining a copy
+ of this software and associated documentation files (the "Software"), to deal
+ in the Software without restriction, including without limitation the rights
+ to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+ copies of the Software, and to permit persons to whom the Software is
+ furnished to do so, subject to the following conditions:
+ .
+ The above copyright notice and this permission notice shall be included in all
+ copies or substantial portions of the Software.
+ .
+ THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+ IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+ FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+ AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+ LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+ SOFTWARE.`,
+
 	"MPL-2.0": ` This Source Code Form is subject to the terms of the Mozilla Public
  License, v. 2.0. If a copy of the MPL was not distributed with this
  file, You can obtain one at http://mozilla.org/MPL/2.0/.
- .
+Comment:
  On Debian systems, the complete text of the MPL-2.0 license can be found
- in "/usr/share/common-licenses/MPL-2.0".
-`,
+ in "/usr/share/common-licenses/MPL-2.0".`,
 }
 
 var githubRegexp = regexp.MustCompile(`github\.com/([^/]+/[^/]+)`)
@@ -64,7 +81,7 @@ func findGitHubOwnerRepo(gopkg string) (string, error) {
 	}
 	resp, err := http.Get("https://" + gopkg + "?go-get=1")
 	if err != nil {
-		return "", err
+		return "", fmt.Errorf("HTTP get: %w", err)
 	}
 	defer resp.Body.Close()
 	z := html.NewTokenizer(resp.Body)
@@ -112,7 +129,7 @@ func findGitHubOwnerRepo(gopkg string) (string, error) {
 func findGitHubRepo(gopkg string) (owner string, repo string, _ error) {
 	ownerrepo, err := findGitHubOwnerRepo(gopkg)
 	if err != nil {
-		return "", "", err
+		return "", "", fmt.Errorf("find GitHub owner repo: %w", err)
 	}
 	parts := strings.Split(ownerrepo, "/")
 	if got, want := len(parts), 2; got != want {
@@ -124,12 +141,12 @@ func findGitHubRepo(gopkg string) (owner string, repo string, _ error) {
 func getLicenseForGopkg(gopkg string) (string, string, error) {
 	owner, repo, err := findGitHubRepo(gopkg)
 	if err != nil {
-		return "", "", err
+		return "", "", fmt.Errorf("find GitHub repo: %w", err)
 	}
 
 	rl, _, err := gitHub.Repositories.License(context.TODO(), owner, repo)
 	if err != nil {
-		return "", "", err
+		return "", "", fmt.Errorf("get license for Go package: %w", err)
 	}
 
 	if deblicense, ok := githubLicenseToDebianLicense[rl.GetLicense().GetKey()]; ok {
@@ -146,21 +163,21 @@ func getLicenseForGopkg(gopkg string) (string, string, error) {
 func getAuthorAndCopyrightForGopkg(gopkg string) (string, string, error) {
 	owner, repo, err := findGitHubRepo(gopkg)
 	if err != nil {
-		return "", "", err
+		return "", "", fmt.Errorf("find GitHub repo: %w", err)
 	}
 
 	rr, _, err := gitHub.Repositories.Get(context.TODO(), owner, repo)
 	if err != nil {
-		return "", "", err
+		return "", "", fmt.Errorf("get repo: %w", err)
 	}
 
 	if strings.TrimSpace(rr.GetOwner().GetURL()) == "" {
-		return "", "", fmt.Errorf("Repository owner URL not present in API response")
+		return "", "", fmt.Errorf("repository owner URL not present in API response")
 	}
 
 	ur, _, err := gitHub.Users.Get(context.TODO(), rr.GetOwner().GetLogin())
 	if err != nil {
-		return "", "", err
+		return "", "", fmt.Errorf("get user: %w", err)
 	}
 
 	copyright := rr.CreatedAt.Format("2006") + " " + ur.GetName()
@@ -178,7 +195,7 @@ func getAuthorAndCopyrightForGopkg(gopkg string) (string, string, error) {
 func getDescriptionForGopkg(gopkg string) (string, error) {
 	owner, repo, err := findGitHubRepo(gopkg)
 	if err != nil {
-		return "", err
+		return "", fmt.Errorf("find GitHub repo: %w", err)
 	}
 
 	rr, _, err := gitHub.Repositories.Get(context.TODO(), owner, repo)
