@@ -15,8 +15,6 @@ const (
 	Mebi
 	Gibi
 	Tebi
-	Pebi
-	Exbi
 )
 
 func humanizeBytes(b int64) string {
